@@ -1,10 +1,8 @@
-/* $XdotOrg: lib/X11/src/xcms/cmsColNm.c,v 1.4 2005-07-03 07:00:55 daniels Exp $ */
-/* $Xorg: cmsColNm.c,v 1.3 2000/08/17 19:45:09 cpqbld Exp $ */
 
 /*
  * Code and supporting documentation (c) Copyright 1990 1991 Tektronix, Inc.
  * 	All Rights Reserved
- * 
+ *
  * This file is a component of an X Window System-specific implementation
  * of Xcms based on the TekColor Color Management System.  Permission is
  * hereby granted to use, copy, modify, sell, and otherwise distribute this
@@ -12,10 +10,10 @@
  * that this copyright, permission, and disclaimer notice is reproduced in
  * all copies of this software and in supporting documentation.  TekColor
  * is a trademark of Tektronix, Inc.
- * 
+ *
  * Tektronix makes no representation about the suitability of this software
  * for any purpose.  It is provided "as is" and with all faults.
- * 
+ *
  * TEKTRONIX DISCLAIMS ALL WARRANTIES APPLICABLE TO THIS SOFTWARE,
  * INCLUDING THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A
  * PARTICULAR PURPOSE.  IN NO EVENT SHALL TEKTRONIX BE LIABLE FOR ANY
@@ -32,7 +30,6 @@
  *
  *
  */
-/* $XFree86: xc/lib/X11/cmsColNm.c,v 3.11 2003/04/13 19:22:20 dawes Exp $ */
 
 #ifdef HAVE_CONFIG_H
 #include <config.h>
@@ -56,7 +53,7 @@ static Status LoadColornameDB(void);
  *		#define declarations local to this package.
  */
 #ifndef XCMSDB
-#define XCMSDB  "/usr/lib/X11/Xcms.txt"
+#define XCMSDB  XCMSDIR "/Xcms.txt"
 #endif
 
 #ifndef isgraph
@@ -187,7 +184,7 @@ _XcmsParseColorString(
  *	DESCRIPTION
  *		Assuming color_string contains a numerical string color
  *		specification, attempts to parse a string into an
- *		XcmsColor structure.		
+ *		XcmsColor structure.
  *
  *	RETURNS
  *		0 if failed; otherwise non-zero.
@@ -257,7 +254,7 @@ FirstCmp(const void *p1, const void *p2)
  *
  */
 {
-    return(strcmp(((XcmsPair *)p1)->first, ((XcmsPair *)p2)->first));
+    return(strcmp(((const XcmsPair *)p1)->first, ((const XcmsPair *)p2)->first));
 }
 
 
@@ -470,7 +467,7 @@ Retry:
 	pair->flag = CYCLE;
 	return(XcmsFailure);
     }
-	    
+
     if (_XcmsParseColorString(ccc, pair->second, pColor) == XcmsSuccess) {
 	/* f2 contains a numerical string specification */
 	return(XcmsSuccess);
@@ -570,7 +567,7 @@ stringSectionSize(
 	return(XcmsFailure);
     }
 
-    while((pBuf = fgets(buf, XCMSDB_MAXLINELEN, stream)) != NULL) {
+    while((fgets(buf, XCMSDB_MAXLINELEN, stream)) != NULL) {
 	if ((sscanf(buf, "%s", token)) && (strcmp(token, END_TOKEN) == 0)) {
 	    break;
 	}
@@ -654,7 +651,7 @@ ReadColornameDB(
      * Process lines between START_TOKEN to END_TOKEN
      */
 
-    while ((pBuf = fgets(buf, XCMSDB_MAXLINELEN, stream)) != NULL) {
+    while ((fgets(buf, XCMSDB_MAXLINELEN, stream)) != NULL) {
 	if ((sscanf(buf, "%s", token)) && (strcmp(token, END_TOKEN) == 0)) {
 	    /*
 	     * Found END_TOKEN so break out of for loop
@@ -816,7 +813,7 @@ _XcmsCopyISOLatin1Lowered(
 
 /*
  *	NAME
- *		_XcmsResolveColorString - 
+ *		_XcmsResolveColorString -
  *
  *	SYNOPSIS
  */
@@ -872,7 +869,7 @@ _XcmsResolveColorString (
 	if (result_format != XcmsUndefinedFormat
 		&& pColor_exact_return->format != result_format) {
 	    /* need to be converted to the target format */
-	    return(XcmsConvertColors(ccc, pColor_exact_return, 1, 
+	    return(XcmsConvertColors(ccc, pColor_exact_return, 1,
 		    result_format, (Bool *)NULL));
 	} else {
 	    return(XcmsSuccess);
