@@ -1,4 +1,3 @@
-/* $Xorg: XKBGAlloc.c,v 1.3 2000/08/17 19:45:01 cpqbld Exp $ */
 /************************************************************
 Copyright (c) 1993 by Silicon Graphics Computer Systems, Inc.
 
@@ -7,24 +6,23 @@ software and its documentation for any purpose and without
 fee is hereby granted, provided that the above copyright
 notice appear in all copies and that both that copyright
 notice and this permission notice appear in supporting
-documentation, and that the name of Silicon Graphics not be 
-used in advertising or publicity pertaining to distribution 
+documentation, and that the name of Silicon Graphics not be
+used in advertising or publicity pertaining to distribution
 of the software without specific prior written permission.
-Silicon Graphics makes no representation about the suitability 
+Silicon Graphics makes no representation about the suitability
 of this software for any purpose. It is provided "as is"
 without any express or implied warranty.
 
-SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS 
-SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY 
+SILICON GRAPHICS DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS
+SOFTWARE, INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
 AND FITNESS FOR A PARTICULAR PURPOSE. IN NO EVENT SHALL SILICON
-GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL 
-DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, 
-DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE 
+GRAPHICS BE LIABLE FOR ANY SPECIAL, INDIRECT OR CONSEQUENTIAL
+DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE,
+DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE
 OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION  WITH
 THE USE OR PERFORMANCE OF THIS SOFTWARE.
 
 ********************************************************/
-/* $XFree86: xc/lib/X11/XKBGAlloc.c,v 3.4 2001/01/17 19:41:48 dawes Exp $ */
 
 #ifdef HAVE_DIX_CONFIG_H
 #include <dix-config.h>
@@ -32,10 +30,6 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <config.h>
 #endif
 
-#define	NEED_EVENTS
-#define	NEED_REPLIES
-
-#ifndef XKB_IN_SERVER
 
 #include <stdio.h>
 #include "Xlibint.h"
@@ -43,27 +37,9 @@ THE USE OR PERFORMANCE OF THIS SOFTWARE.
 #include <X11/extensions/XKBgeom.h>
 #include <X11/extensions/XKBproto.h>
 
-#else 
-
-#include <stdio.h>
-#include <X11/X.h>
-#include <X11/Xproto.h>
-#include "misc.h"
-#include "inputstr.h"
-#include <X11/extensions/XKBsrv.h>
-#include <X11/extensions/XKBgeom.h>
-
-#endif /* XKB_IN_SERVER */
-
-#ifdef X_NOT_POSIX
-#define Size_t unsigned int
-#else
-#define Size_t size_t
-#endif
-
 /***====================================================================***/
 
-static void 
+static void
 _XkbFreeGeomLeafElems(	Bool			freeAll,
 			int			first,
 			int 			count,
@@ -77,14 +53,14 @@ _XkbFreeGeomLeafElems(	Bool			freeAll,
 	if (*elems!=NULL) {
 	    _XkbFree(*elems);
 	    *elems= NULL;
-	}	
+	}
 	return;
     }
 
     if ((first>=(*num_inout))||(first<0)||(count<1))
 	return;
 
-    if (first+count>=(*num_inout)) { 
+    if (first+count>=(*num_inout)) {
 	/* truncating the array is easy */
 	(*num_inout)= first;
     }
@@ -104,7 +80,7 @@ typedef void (*ContentsClearFunc)(
 		char *		/* priv */
 );
 
-static void 
+static void
 _XkbFreeGeomNonLeafElems(	Bool			freeAll,
 				int			first,
 				int 			count,
@@ -192,7 +168,7 @@ XkbFreeGeomKeyAliases(	XkbGeometryPtr	geom,
 			int		first,
 			int		count,
 			Bool		freeAll)
-{	
+{
     _XkbFreeGeomLeafElems(freeAll,first,count,
 				&geom->num_key_aliases,&geom->sz_key_aliases,
 				(char **)&geom->key_aliases,
@@ -253,7 +229,7 @@ XkbFreeGeomOutlines(XkbShapePtr	shape,int first,int count,Bool freeAll)
 				&shape->num_outlines,&shape->sz_outlines,
 				(char **)&shape->outlines,
 				sizeof(XkbOutlineRec),_XkbClearOutline);
-	
+
     return;
 }
 
@@ -281,7 +257,7 @@ XkbFreeGeomShapes(XkbGeometryPtr geom,int first,int count,Bool freeAll)
 
 /***====================================================================***/
 
-void 
+void
 XkbFreeGeomOverlayKeys(XkbOverlayRowPtr row,int first,int count,Bool freeAll)
 {
     _XkbFreeGeomLeafElems(freeAll,first,count,
@@ -402,7 +378,7 @@ _XkbClearDoodad(char *doodad_in)
 XkbDoodadPtr	doodad= (XkbDoodadPtr)doodad_in;
 
     switch (doodad->any.type) {
-   	case XkbTextDoodad: 
+   	case XkbTextDoodad:
 	    {
 		if (doodad->text.text!=NULL) {
 		    _XkbFree(doodad->text.text);
@@ -414,7 +390,7 @@ XkbDoodadPtr	doodad= (XkbDoodadPtr)doodad_in;
 		}
 	    }
 	    break;
-   	case XkbLogoDoodad: 
+   	case XkbLogoDoodad:
 	    {
 		if (doodad->logo.logo_name!=NULL) {
 		    _XkbFree(doodad->logo.logo_name);
@@ -481,7 +457,7 @@ _XkbGeomAlloc(	XPointer *		old,
 		unsigned short *	num,
 		unsigned short *	total,
 		int			num_new,
-		Size_t			sz_elem)
+		size_t			sz_elem)
 {
     if (num_new<1)
 	return Success;
@@ -547,7 +523,7 @@ _XkbGeomAlloc(	XPointer *		old,
 #define	_XkbAllocOverlayKeys(r,n) _XkbGeomAlloc((XPointer *)&(r)->keys,\
 				&(r)->num_keys,&(r)->sz_keys,\
 				(n),sizeof(XkbOverlayKeyRec))
-    
+
 Status
 XkbAllocGeomProps(XkbGeometryPtr geom,int nProps)
 {
@@ -689,28 +665,24 @@ register XkbPropertyPtr prop;
 	if ((prop->name)&&(strcmp(name,prop->name)==0)) {
 	    if (prop->value)
 		_XkbFree(prop->value);
-	    prop->value= (char *)_XkbAlloc(strlen(value)+1);
-	    if (prop->value)
-		strcpy(prop->value,value);
+	    prop->value= strdup(value);
 	    return prop;
-	}    
+	}
     }
     if ((geom->num_properties>=geom->sz_properties)&&
 					(_XkbAllocProps(geom,1)!=Success)) {
 	return NULL;
     }
     prop= &geom->properties[geom->num_properties];
-    prop->name= (char *)_XkbAlloc(strlen(name)+1);
-    if (!name)
+    prop->name= strdup(name);
+    if (!prop->name)
 	return NULL;
-    strcpy(prop->name,name);
-    prop->value= (char *)_XkbAlloc(strlen(value)+1);
-    if (!value) {
+    prop->value= strdup(value);
+    if (!prop->value) {
 	_XkbFree(prop->name);
 	prop->name= NULL;
 	return NULL;
     }
-    strcpy(prop->value,value);
     geom->num_properties++;
     return prop;
 }
@@ -762,10 +734,9 @@ register XkbColorPtr color;
     }
     color= &geom->colors[geom->num_colors];
     color->pixel= pixel;
-    color->spec= (char *)_XkbAlloc(strlen(spec)+1);
+    color->spec= strdup(spec);
     if (!color->spec)
 	return NULL;
-    strcpy(color->spec,spec);
     geom->num_colors++;
     return color;
 }
@@ -950,7 +921,7 @@ Bool		found;
 	}
     }
     if (!found)
-   	return NULL; 
+   	return NULL;
     if ((row->num_keys>=row->sz_keys)&&(_XkbAllocOverlayKeys(row,1)!=Success))
 	return NULL;
     key= &row->keys[row->num_keys];
